﻿using System.Text;
using System.Text.RegularExpressions;

namespace OpenAIClient
{
    internal class Program
    {
        private const string ApiKey = "KEY";
        private const string Model = "qwen3-30b-a3b";
        private static readonly Regex CommentRegex =
            new(@"(\/\*[\s\S]*?\*\/|\/\/[^\r\n]*)",
                RegexOptions.Compiled);
        private static string Translate(string raw)
        {
            // 去掉注释定界符
            var content = raw.StartsWith("/*")
                ? raw[2..^2]
                : raw[2..];

            content = content.Trim();
            if (string.IsNullOrEmpty(content))
                return raw;                          // 空注释直接返回

            string zh = OpenAI.CallOpenAISync(
                ApiKey,
                Model,
                $"你是一位专业的翻译员,将下面的内容翻译成中文,不允许输出除了翻译内容以外的内容,需要翻译的内容:{content}\n/no_think"
            ).TrimStart('\n').Trim();
            Console.WriteLine(zh);
            if (raw.StartsWith("/*"))
                return $"/* {zh} */";

            // 处理包含换行的 // 注释
            var lines = zh.Split(new[] { "\r\n", "\n", "\r" },
                                 StringSplitOptions.RemoveEmptyEntries);
            return "// " + string.Join(Environment.NewLine + "// ", lines);
        }

        public static void Run(string srcPath, string dstPath)
        {
            var source = File.ReadAllText(srcPath);

            // 简单缓存，避免重复翻译相同内容
            var cache = new Dictionary<string, string>();

            string result = CommentRegex.Replace(source, match =>
            {
                var key = match.Value;
                if (!cache.TryGetValue(key, out var translated))
                {
                    try
                    {
                        translated = Translate(key);
                        cache[key] = translated;
                    }
                    catch (Exception ex)
                    {
                        // 失败时保留原文并在行尾加标记
                        translated = key + " /* 翻译失败: " + ex.Message + " */";
                    }
                }
                return translated;
            });

            File.WriteAllText(dstPath, result, Encoding.UTF8);
            Console.WriteLine($"翻译完成: {dstPath}");
        }


        static void Main(string[] args)
        {
            Run(
    @"D:\Projects\M1\PML\hv\IA32\ia32.h",
    @"D:\Projects\M1\PML\hv\IA32\ia32.zh.h");
            Console.WriteLine("OK");


        }
    }
}
